import mysql from 'mysql2/promise';

const pool = mysql.createPool({
  host: import.meta.env.VITE_DB_HOST || 'db.pandem.fr',
  user: import.meta.env.VITE_DB_USER || 'proxdash',
  password: import.meta.env.VITE_DB_PASSWORD || 'proxdash',
  database: import.meta.env.VITE_DB_NAME || 'proxdash',
  waitForConnections: true,
  connectionLimit: 10,
  maxIdle: 10,
  idleTimeout: 60000,
  queueLimit: 0,
});

export async function getServers() {
  const [rows] = await pool.query('SELECT * FROM servers ORDER BY created_at ASC');
  return rows;
}

export async function addServer(server: {
  name: string;
  model: string;
  cpu_model: string;
  ram_gb: number;
  influx_enabled: boolean;
  influx_org?: string;
  influx_token?: string;
  influx_url?: string;
}) {
  const [result] = await pool.query(
    'INSERT INTO servers (name, model, cpu_model, ram_gb, influx_enabled, influx_org, influx_token, influx_url) VALUES (?, ?, ?, ?, ?, ?, ?, ?)',
    [
      server.name,
      server.model,
      server.cpu_model,
      server.ram_gb,
      server.influx_enabled,
      server.influx_org || null,
      server.influx_token || null,
      server.influx_url || null,
    ]
  );
  return result;
}

export default pool;